hs-bingen-traits

Utility traits behind hs-bindgen ergonomics. It helps user to easily define wrapper function to derive a Rust type from and into a C-FFI safe target type (that match the memory layout of an Haskell type).

Enums

Enumeration of all Haskell F-FFI safe types as the string representation of their token in Haskell.

Traits

Generate C-FFI safe wrapper from a given Rust type.
Turn a given Rust type into his HsType target.
Generate Rust safe wrapper from a given C-FFI type.