Enum hs_bindgen_traits::HsType
source · [−]Expand description
Enumeration of all Haskell F-FFI safe types as the string representation of their token in Haskell.
Variants
CString
Empty
IO(Box<HsType>)
Implementations
sourceimpl HsType
impl HsType
sourcepub fn quote(&self) -> TokenStream
pub fn quote(&self) -> TokenStream
Get the C-FFI Rust type that match the memory layout of a given HsType.
This function return a OUTPUT: proc_macro2::TokenStream that should
be valid (considered as FFI-safe by rustc) in the context of a block
of form: quote! { extern C fn _(_: #OUTPUT) {} }